==> appboxo_sdk-0.1.15.tar.gz: ios/Classes/SwiftAppboxoSdkPlugin.swift <==
/*
 Copyright 2020 Appboxo pte. ltd.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
 http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

import Flutter
import UIKit
import AppBoxoSDK


public class SwiftAppboxoSdkPlugin: NSObject, FlutterPlugin {
    
    private let customEventsStreamHandler = CustomEventsStreamHandler()
    private let lifecycleEventsStreamHandler = LifecycleEventsStreamHandler()
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = SwiftAppboxoSdkPlugin()
        
        let channel = FlutterMethodChannel(name: "appboxo_sdk", binaryMessenger: registrar.messenger())
        registrar.addMethodCallDelegate(instance, channel: channel)
        
        let customEventChannel = FlutterEventChannel(name: "appboxo_sdk_custom_events", binaryMessenger: registrar.messenger())
        let lifecycleChannel = FlutterEventChannel(name: "appboxo_sdk_lifecycle", binaryMessenger: registrar.messenger())
        
        customEventChannel.setStreamHandler(instance.customEventsStreamHandler)
        lifecycleChannel.setStreamHandler(instance.lifecycleEventsStreamHandler)
    }
    
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        switch call.method {
        case "setConfig":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let clientId = arguments["client_id"] as? String ?? ""
            let theme = arguments["theme"] as? String ?? ""
            var globalTheme : Theme = .System
            switch (theme) {
                case "dark": globalTheme = .Dark
                case "light": globalTheme = .Light
                default: globalTheme = .System
            }
            AppBoxo.shared.setConfig(config: Config(clientId: clientId, theme: globalTheme))
        case "openMiniApp":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let appId = arguments["app_id"] as? String ?? ""
            let payload = arguments["payload"] as? String ?? ""
            let data = arguments["data"] as? [String: Any] ?? [:]
            let theme = arguments["theme"] as? String ?? ""

            var miniappTheme : Theme? = nil
            switch theme {
            case "dark":
                miniappTheme = .Dark
            case "light":
                miniappTheme = .Light
            case "system":
                miniappTheme = .System
            default:
                miniappTheme = nil
            }

            let miniApp = AppBoxo.shared.getMiniApp(appId: appId, authPayload: payload, data: data)
            miniApp.delegate = self
            if let theme = miniappTheme {
                miniApp.setConfig(config: MiniAppConfig(theme: theme))
            }
            miniApp.open(viewController: UIApplication.shared.delegate!.window!!.rootViewController!)
            break
        case "sendEvent":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let map = arguments["custom_event"] as? [String: Any] ?? [:]
            let appId = map["appId"] as? String ?? ""
            
            var params = [
                "request_id" : map["requestId"] ?? 0,
                "type" : map["type"] ?? "",
                "payload" : map["payload"] ?? [String : Any]()
                ] as [String: Any]
            
            if let errorType = map["errorType"] as? String {
                params["error_type"] = errorType
            }
            
            AppBoxo.shared.getMiniApp(appId: appId)?.sendEvent(params: params)
            break
        case "hideAllMiniApps":
            AppBoxo.shared.hideAllMiniApps()
            break
        case "logout":
            AppBoxo.shared.logout()
            break
        default:
            break
        }
    }
}

extension SwiftAppboxoSdkPlugin : MiniAppDelegate {
    public func didReceiveCustomEvent(miniApp: MiniApp, params: [String : Any]) {
        var dict = [
            "appId" : miniApp.appId,
            "requestId" : "\(params["request_id"] ?? 0)",
            "type" : params["type"] ?? "",
            "payload" : params["payload"] ?? [String : Any]()
            ] as [String: Any]
        
        if let errorType = params["errorType"] as? String {
            dict["error_type"] = errorType
        }
        
        customEventsStreamHandler.events?(dict)
    }
    
    public func onLaunch(miniApp: MiniApp) {
        let dict = [
            "appId" : miniApp.appId,
            "lifecycle" : "onLaunch"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onResume(miniApp: MiniApp) {
        let dict = [
            "appId" : miniApp.appId,
            "lifecycle" : "onResume"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onPause(miniApp: MiniApp) {
        let dict = [
            "appId" : miniApp.appId,
            "lifecycle" : "onPause"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onClose(miniApp: MiniApp) {
        let dict = [
            "appId" : miniApp.appId,
            "lifecycle" : "onClose"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onError(miniApp: MiniApp, message: String) {
        let dict = [
            "appId" : miniApp.appId,
            "lifecycle" : "onError",
            "error" : message
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
}

==> appboxo_sdk-0.1.17.tar.gz: ios/Classes/SwiftAppboxoSdkPlugin.swift <==
/*
 Copyright 2020 Appboxo pte. ltd.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
 http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

import Flutter
import UIKit
import AppBoxoSDK


public class SwiftAppboxoSdkPlugin: NSObject, FlutterPlugin {
    
    private let customEventsStreamHandler = CustomEventsStreamHandler()
    private let lifecycleEventsStreamHandler = LifecycleEventsStreamHandler()
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let instance = SwiftAppboxoSdkPlugin()
        
        let channel = FlutterMethodChannel(name: "appboxo_sdk", binaryMessenger: registrar.messenger())
        registrar.addMethodCallDelegate(instance, channel: channel)
        
        let customEventChannel = FlutterEventChannel(name: "appboxo_sdk_custom_events", binaryMessenger: registrar.messenger())
        let lifecycleChannel = FlutterEventChannel(name: "appboxo_sdk_lifecycle", binaryMessenger: registrar.messenger())
        
        customEventChannel.setStreamHandler(instance.customEventsStreamHandler)
        lifecycleChannel.setStreamHandler(instance.lifecycleEventsStreamHandler)
    }
    
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        switch call.method {
        case "setConfig":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let clientId = arguments["client_id"] as? String ?? ""
            let theme = arguments["theme"] as? String ?? ""
            var globalTheme : Theme = .System
            switch (theme) {
                case "dark": globalTheme = .Dark
                case "light": globalTheme = .Light
                default: globalTheme = .System
            }
            Appboxo.shared.setConfig(config: Config(clientId: clientId, theme: globalTheme))
        case "openMiniApp":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let appId = arguments["app_id"] as? String ?? ""
            let payload = arguments["payload"] as? String ?? ""
            let data = arguments["data"] as? [String: Any] ?? [:]
            let theme = arguments["theme"] as? String ?? ""

            var miniappTheme : Theme? = nil
            switch theme {
            case "dark":
                miniappTheme = .Dark
            case "light":
                miniappTheme = .Light
            case "system":
                miniappTheme = .System
            default:
                miniappTheme = nil
            }

            let miniApp = Appboxo.shared.getMiniapp(appId: appId, authPayload: payload, data: data)
            miniApp.delegate = self
            if let theme = miniappTheme {
                miniApp.setConfig(config: MiniappConfig(theme: theme))
            }
            miniApp.open(viewController: UIApplication.shared.delegate!.window!!.rootViewController!)
            break
        case "sendEvent":
            guard let arguments = call.arguments as? [String : Any] else { return }
            let map = arguments["custom_event"] as? [String: Any] ?? [:]
            let appId = map["appId"] as? String ?? ""
            
            var params = [
                "request_id" : map["requestId"] ?? 0,
                "type" : map["type"] ?? "",
                "payload" : map["payload"] ?? [String : Any]()
                ] as [String: Any]
            
            if let errorType = map["errorType"] as? String {
                params["error_type"] = errorType
            }
            
            Appboxo.shared.getMiniapp(appId: appId)?.sendEvent(params: params)
            break
        case "hideAllMiniApps":
            Appboxo.shared.hideMiniapps()
            break
        case "logout":
            Appboxo.shared.logout()
            break
        default:
            break
        }
    }
}

extension SwiftAppboxoSdkPlugin : MiniappDelegate {
    public func didReceiveCustomEvent(miniapp: Miniapp, params: [String : Any]) {
        var dict = [
            "appId" : miniapp.appId,
            "requestId" : "\(params["request_id"] ?? 0)",
            "type" : params["type"] ?? "",
            "payload" : params["payload"] ?? [String : Any]()
            ] as [String: Any]
        
        if let errorType = params["errorType"] as? String {
            dict["error_type"] = errorType
        }
        
        customEventsStreamHandler.events?(dict)
    }
    
    public func onLaunch(miniapp: Miniapp) {
        let dict = [
            "appId" : miniapp.appId,
            "lifecycle" : "onLaunch"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onResume(miniapp: Miniapp) {
        let dict = [
            "appId" : miniapp.appId,
            "lifecycle" : "onResume"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onPause(miniapp: Miniapp) {
        let dict = [
            "appId" : miniapp.appId,
            "lifecycle" : "onPause"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onClose(miniapp: Miniapp) {
        let dict = [
            "appId" : miniapp.appId,
            "lifecycle" : "onClose"
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
    
    public func onError(miniapp: Miniapp, message: String) {
        let dict = [
            "appId" : miniapp.appId,
            "lifecycle" : "onError",
            "error" : message
        ]
        
        lifecycleEventsStreamHandler.events?(dict)
    }
}
